@@ -35,6 +35,7 @@ if getattr(sys, "frozen", False):
 else:
     app_path = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
 sys.path.append(app_path)
+chip_path = os.path.join(app_path, "chips")
 
 try:
     import changeconf as cgc
@@ -110,13 +111,13 @@ def bl_create_flash_default_data(length):
 def generate_romfs_img(romfs_dir, dst_img_name):
     exe = None
     if os.name == 'nt':
-        exe = os.path.join(app_path, 'common/genromfs', 'genromfs.exe')
+        exe = os.path.join(app_path, 'utils/genromfs', 'genromfs.exe')
     elif os.name == 'posix':
         machine = os.uname().machine
         if machine == 'x86_64':
-            exe = os.path.join(app_path, 'common/genromfs', 'genromfs_amd64')
+            exe = os.path.join(app_path, 'utils/genromfs', 'genromfs_amd64')
         elif machine == 'armv7l':
-            exe = os.path.join(app_path, 'common/genromfs', 'genromfs_armel')
+            exe = os.path.join(app_path, 'utils/genromfs', 'genromfs_armel')
     if exe is None:
         bflb_utils.printf('NO supported genromfs exe for your platform!')
         return -1
@@ -145,44 +146,44 @@ class BflbIotTool(object):
         self.config = {}
         self.chipname = chipname
         self.chiptype = chiptype
-        self.eflash_loader_t = bflb_eflash_loader.BflbEflashLoader()
+        self.eflash_loader_t = bflb_eflash_loader.BflbEflashLoader(chipname, chiptype)
      
-        eflash_loader_cfg_org = os.path.join(app_path, chipname, "eflash_loader/eflash_loader_cfg.conf")
-        self.eflash_loader_cfg = os.path.join(app_path, chipname, "eflash_loader/eflash_loader_cfg.ini")
+        eflash_loader_cfg_org = os.path.join(chip_path, chipname, "eflash_loader/eflash_loader_cfg.conf")
+        self.eflash_loader_cfg = os.path.join(chip_path, chipname, "eflash_loader/eflash_loader_cfg.ini")
         if os.path.isfile(self.eflash_loader_cfg) is False:
             shutil.copy(eflash_loader_cfg_org, self.eflash_loader_cfg)
         if chiptype == "bl60x":
-            bh_cfg_file_org = os.path.join(app_path, chipname,
+            bh_cfg_file_org = os.path.join(chip_path, chipname,
                                            "efuse_bootheader/efuse_bootheader_cfg_dp.conf")
         else:
-            bh_cfg_file_org = os.path.join(app_path, chipname,
+            bh_cfg_file_org = os.path.join(chip_path, chipname,
                                            "efuse_bootheader/efuse_bootheader_cfg.conf")
-        self.bh_cfg_file = os.path.join(app_path, chipname, "efuse_bootheader/efuse_bootheader_cfg.ini")
+        self.bh_cfg_file = os.path.join(chip_path, chipname, "efuse_bootheader/efuse_bootheader_cfg.ini")
         if os.path.isfile(self.bh_cfg_file) is False:
             shutil.copy(bh_cfg_file_org, self.bh_cfg_file)
         
-        ini_file_kw = 'efuse_bootheader_cfg_'
-        ini_file_kw_len = len(ini_file_kw)
-        chip_flash_type_config = {}
-        bl60x_boards = set()
-        bl60x_board_xtal = set()
-        bl_factory_params_file_prefix_len = len(bl_factory_params_file_prefix)
-        self.bl60x_boards_xtal_selectbox = []
-        self.bl60x_boards_selectbox = []
-        try:
-            bl_factory_params_files = os.listdir(os.path.join(app_path, chipname, 'device_tree'))
-            for bl_fac_p_f in bl_factory_params_files:
-                if not os.path.isdir(bl_fac_p_f):
-                    drop_idx_start = bl_fac_p_f.find(bl_factory_params_file_prefix)
-                    if drop_idx_start != -1:
-                        drop_idx_end = drop_idx_start + bl_factory_params_file_prefix_len
-                        drop_value_l = bl_fac_p_f[drop_idx_end:-4].split('_')
-                        bl60x_boards.add(drop_value_l[0].strip())
-                        bl60x_board_xtal.add(drop_value_l[1].strip())
-            self.bl60x_boards_selectbox = list(bl60x_boards)
-            self.bl60x_boards_xtal_selectbox = list(bl60x_board_xtal)
-        except Exception as e:
-            bflb_utils.printf(e)
+#         ini_file_kw = 'efuse_bootheader_cfg_'
+#         ini_file_kw_len = len(ini_file_kw)
+#         chip_flash_type_config = {}
+#         bl60x_boards = set()
+#         bl60x_board_xtal = set()
+#         bl_factory_params_file_prefix_len = len(bl_factory_params_file_prefix)
+#         self.bl60x_boards_xtal_selectbox = []
+#         self.bl60x_boards_selectbox = []
+#         try:
+#             bl_factory_params_files = os.listdir(os.path.join(chip_path, chipname, 'device_tree'))
+#             for bl_fac_p_f in bl_factory_params_files:
+#                 if not os.path.isdir(bl_fac_p_f):
+#                     drop_idx_start = bl_fac_p_f.find(bl_factory_params_file_prefix)
+#                     if drop_idx_start != -1:
+#                         drop_idx_end = drop_idx_start + bl_factory_params_file_prefix_len
+#                         drop_value_l = bl_fac_p_f[drop_idx_end:-4].split('_')
+#                         bl60x_boards.add(drop_value_l[0].strip())
+#                         bl60x_board_xtal.add(drop_value_l[1].strip())
+#             self.bl60x_boards_selectbox = list(bl60x_boards)
+#             self.bl60x_boards_xtal_selectbox = list(bl60x_board_xtal)
+#         except Exception as e:
+#             bflb_utils.printf(e)
 
 
     def bl60x_fw_boot_head_gen(self,
@@ -218,6 +219,9 @@ class BflbIotTool(object):
             if cpu_type is not None:
                 cfg.set(bootheader_section_name, 'halt_cpu1', '1')
             #cfg.set(bootheader_section_name, 'key_sel', '0')
+        else:
+            if chiptype == "bl60x":
+                cfg.set(bootheader_section_name, 'halt_cpu1', '0')
     
         if encrypt:
             cfg.set(bootheader_section_name, 'encrypt_type', '1')
@@ -281,19 +285,19 @@ class BflbIotTool(object):
                             privatekey=None,
                             cfg_ini=None,
                             cpu_type=None):
-        efuse_file = os.path.join(app_path, chipname, "efuse_bootheader/efusedata.bin")
-        efuse_mask_file = os.path.join(app_path, chipname, "efuse_bootheader/efusedata_mask.bin")
+        efuse_file = os.path.join(chip_path, chipname, "efuse_bootheader/efusedata.bin")
+        efuse_mask_file = os.path.join(chip_path, chipname, "efuse_bootheader/efusedata_mask.bin")
         if chiptype == "bl60x":
-            bh_file = os.path.join(app_path, chipname, "efuse_bootheader/bootheader_cpu0.bin")
+            bh_file = os.path.join(chip_path, chipname, "efuse_bootheader/bootheader_cpu0.bin")
         else:
-            bh_file = os.path.join(app_path, chipname, "efuse_bootheader/bootheader.bin")
+            bh_file = os.path.join(chip_path, chipname, "efuse_bootheader/bootheader.bin")
         cfg = BFConfigParser()
         if cfg_ini in [None, '']:
             if chiptype == "bl60x":
-                f_org = os.path.join(app_path, chipname, "img_create_iot", "img_create_cfg_dp.conf")
+                f_org = os.path.join(chip_path, chipname, "img_create_iot", "img_create_cfg_dp.conf")
             else:
-                f_org = os.path.join(app_path, chipname, "img_create_iot", "img_create_cfg.conf")
-            f = os.path.join(app_path, chipname, "img_create_iot", "img_create_cfg.ini")
+                f_org = os.path.join(chip_path, chipname, "img_create_iot", "img_create_cfg.conf")
+            f = os.path.join(chip_path, chipname, "img_create_iot", "img_create_cfg.ini")
             if os.path.isfile(f) is False:
                 shutil.copy(f_org, f)
         else:
@@ -301,17 +305,17 @@ class BflbIotTool(object):
         cfg.read(f)
         if bintype == "fw":
             if cpu_type is None:
-                bootinfo_file = os.path.join(app_path, chipname, "img_create_iot", "bootinfo.bin")
-                img_file = os.path.join(app_path, chipname, "img_create_iot", "img.bin")
+                bootinfo_file = os.path.join(chip_path, chipname, "img_create_iot", "bootinfo.bin")
+                img_file = os.path.join(chip_path, chipname, "img_create_iot", "img.bin")
             else:
-                bootinfo_file = os.path.join(app_path, chipname,
+                bootinfo_file = os.path.join(chip_path, chipname,
                                              "img_create_iot", "bootinfo_{0}.bin".format(cpu_type.lower()))
-                img_file = os.path.join(app_path, chipname,
+                img_file = os.path.join(chip_path, chipname,
                                         "img_create_iot", "img_{0}.bin".format(cpu_type.lower()))
         else:
-            bootinfo_file = os.path.join(app_path, chipname,
+            bootinfo_file = os.path.join(chip_path, chipname,
                                          "img_create_iot", "bootinfo_{0}.bin".format(bintype))
-            img_file = os.path.join(app_path, chipname, "img_create_iot", "img_{0}.bin".format(bintype))
+            img_file = os.path.join(chip_path, chipname, "img_create_iot", "img_{0}.bin".format(bintype))
     
         if cpu_type is not None:
             img_section_name = "Img_" + cpu_type + "_Cfg"
@@ -339,7 +343,7 @@ class BflbIotTool(object):
     
     
     def bl60x_mfg_ota_header(self, chipname, file_bytearray, use_xz):
-        ota_cfg = os.path.join(app_path, chipname, "conf/ota.toml")
+        ota_cfg = os.path.join(chip_path, chipname, "conf/ota.toml")
         parsed_toml = toml.load(ota_cfg)
         header_len = 512
         header = bytearray()
@@ -414,17 +418,17 @@ class BflbIotTool(object):
         fw_ota_bin = bytearray()
         fw_ota_bin_xz = bytearray()
         if cpu_type is None:
-            fw_ota_path = os.path.join(app_path, chipname, "ota/FW_OTA.bin")
+            fw_ota_path = os.path.join(chip_path, chipname, "ota/FW_OTA.bin")
         else:
-            fw_ota_path = os.path.join(app_path, chipname, "ota/" + cpu_type + "_OTA.bin")
+            fw_ota_path = os.path.join(chip_path, chipname, "ota/" + cpu_type + "_OTA.bin")
         with open(fw_ota_path, mode="rb") as bin_f:
             file_bytes = bin_f.read()
             for b in file_bytes:
                 fw_ota_bin.append(b)
         if cpu_type is None:
-            fw_ota_path = os.path.join(app_path, chipname, "ota/FW_OTA.bin.xz")
+            fw_ota_path = os.path.join(chip_path, chipname, "ota/FW_OTA.bin.xz")
         else:
-            fw_ota_path = os.path.join(app_path, chipname, "ota/" + cpu_type + "_OTA.bin.xz")
+            fw_ota_path = os.path.join(chip_path, chipname, "ota/" + cpu_type + "_OTA.bin.xz")
         with lzma.open(fw_ota_path, mode="wb", check=lzma.CHECK_CRC32,
                        filters=bl60x_xz_filters) as xz_f:
             xz_f.write(fw_ota_bin)
@@ -436,9 +440,9 @@ class BflbIotTool(object):
         for b in fw_ota_bin_xz:
             fw_ota_bin_xz_ota.append(b)
         if cpu_type is None:
-            fw_ota_path = os.path.join(app_path, chipname, "ota/FW_OTA.bin.xz.ota")
+            fw_ota_path = os.path.join(chip_path, chipname, "ota/FW_OTA.bin.xz.ota")
         else:
-            fw_ota_path = os.path.join(app_path, chipname, "ota/" + cpu_type + "_OTA.bin.xz.ota")
+            fw_ota_path = os.path.join(chip_path, chipname, "ota/" + cpu_type + "_OTA.bin.xz.ota")
         with open(fw_ota_path, mode="wb") as f:
             f.write(fw_ota_bin_xz_ota)
         with open(fw_ota_path.replace(".ota", ".hash"), mode="wb") as f:
@@ -449,14 +453,14 @@ class BflbIotTool(object):
         fw_header_len = 4096
         fw_ota_bin = bytearray()
     
-        ota_path = os.path.join(app_path, chipname, "ota")
+        ota_path = os.path.join(chip_path, chipname, "ota")
         if os.path.isdir(ota_path) is False:
             os.mkdir(ota_path)
     
         if cpu_type is None:
-            bootinfo_fw_path = os.path.join(app_path, chipname, "img_create_iot", "bootinfo.bin")
+            bootinfo_fw_path = os.path.join(chip_path, chipname, "img_create_iot", "bootinfo.bin")
         else:
-            bootinfo_fw_path = os.path.join(app_path, chipname,
+            bootinfo_fw_path = os.path.join(chip_path, chipname,
                                             "img_create_iot", "bootinfo_" + cpu_type.lower() + ".bin")
         with open(bootinfo_fw_path, mode="rb") as f:
             file_bytes = f.read(4096)
@@ -469,9 +473,9 @@ class BflbIotTool(object):
             i = i - 1
         bflb_utils.printf("FW OTA bin header is Done. Len is %d" % len(fw_ota_bin))
         if cpu_type is None:
-            img_fw_path = os.path.join(app_path, chipname, "img_create_iot", "img.bin")
+            img_fw_path = os.path.join(chip_path, chipname, "img_create_iot", "img.bin")
         else:
-            img_fw_path = os.path.join(app_path, chipname,
+            img_fw_path = os.path.join(chip_path, chipname,
                                        "img_create_iot", "img_" + cpu_type.lower() + ".bin")
         with open(img_fw_path, mode="rb") as f:
             file_bytes = f.read()
@@ -479,17 +483,17 @@ class BflbIotTool(object):
                 fw_ota_bin.append(b)
         fw_ota_bin_header = self.bl60x_mfg_ota_header(chipname, fw_ota_bin, use_xz=0)
         if cpu_type is None:
-            fw_ota_path = os.path.join(app_path, chipname, "ota/FW_OTA.bin")
+            fw_ota_path = os.path.join(chip_path, chipname, "ota/FW_OTA.bin")
         else:
-            fw_ota_path = os.path.join(app_path, chipname, "ota/" + cpu_type + "_OTA.bin")
+            fw_ota_path = os.path.join(chip_path, chipname, "ota/" + cpu_type + "_OTA.bin")
         with open(fw_ota_path, mode="wb") as f:
             f.write(fw_ota_bin)
         for b in fw_ota_bin:
             fw_ota_bin_header.append(b)
         if cpu_type is None:
-            fw_ota_path = os.path.join(app_path, chipname, "ota/FW_OTA.bin.ota")
+            fw_ota_path = os.path.join(chip_path, chipname, "ota/FW_OTA.bin.ota")
         else:
-            fw_ota_path = os.path.join(app_path, chipname, "ota/" + cpu_type + "_OTA.bin.ota")
+            fw_ota_path = os.path.join(chip_path, chipname, "ota/" + cpu_type + "_OTA.bin.ota")
         with open(fw_ota_path, mode="wb") as f:
             f.write(fw_ota_bin_header)
         bflb_utils.printf("FW OTA bin is Done. Len is %d" % len(fw_ota_bin))
@@ -510,7 +514,7 @@ class BflbIotTool(object):
                         cfg_ini=None):
         # python bflb_img_create.py -c np -i media -s none
         f = self.bl60x_image_gen_cfg(chipname, chiptype, raw_bin_name, bintype, key, iv, publickey, privarekey, cfg_ini, cpu_type)
-        if key or (publickey is not None and privarekey is not None):
+        if key or (publickey and privarekey):
             img_cfg = BFConfigParser()
             img_cfg.read(f)
             efusefile = img_cfg.get("Img_Cfg", "efuse_file")
@@ -580,7 +584,7 @@ class BflbIotTool(object):
     def bl_write_flash_img(self, d_addrs, d_files, flash_size):
         whole_img_len = bl_get_largest_addr(d_addrs, d_files)
         whole_img_data = bl_create_flash_default_data(whole_img_len)
-        whole_img_file = os.path.join(app_path, self.chipname, "img_create_iot", "whole_flash_data.bin")
+        whole_img_file = os.path.join(chip_path, self.chipname, "img_create_iot", "whole_flash_data.bin")
         filedatas = bl_get_file_data(d_files)
         # create_whole_image_flash
         for i in range(len(d_addrs)):
@@ -605,7 +609,7 @@ class BflbIotTool(object):
         d_files = []
         d_addrs = []
         bind_bootinfo = True
-        chipnamedir = os.path.join(app_path, chipname)
+        chipnamedir = os.path.join(chip_path, chipname)
     
         if pt_parcel is None:
             bflb_utils.set_error_code("007B")
@@ -617,31 +621,31 @@ class BflbIotTool(object):
                 whole_img_len = 0x2000 + os.path.getsize(
                     chipnamedir + "/img_create_iot/img_boot2.bin")
                 whole_img_data = bl_create_flash_default_data(whole_img_len)
-                filedata = bl_get_file_data([chipname + "/img_create_iot/bootinfo_boot2.bin"])[0]
+                filedata = bl_get_file_data(["chips/" + chipname + "/img_create_iot/bootinfo_boot2.bin"])[0]
                 whole_img_data[0:len(filedata)] = filedata
-                filedata = bl_get_file_data([chipname + "/img_create_iot/img_boot2.bin"])[0]
+                filedata = bl_get_file_data(["chips/" + chipname + "/img_create_iot/img_boot2.bin"])[0]
                 whole_img_data[0x2000:0x2000 + len(filedata)] = filedata
                 fp = open(whole_img, 'wb+')
                 fp.write(whole_img_data)
                 fp.close()
-                d_files.append(chipname + "/img_create_iot/whole_img_boot2.bin")
+                d_files.append("chips/" + chipname + "/img_create_iot/whole_img_boot2.bin")
                 d_addrs.append("00000000")
             else:
-                d_files.append(chipname + "/img_create_iot/bootinfo_boot2.bin")
+                d_files.append("chips/" + chipname + "/img_create_iot/bootinfo_boot2.bin")
                 d_addrs.append("00000000")
-                d_files.append(chipname + "/img_create_iot/img_boot2.bin")
+                d_files.append("chips/" + chipname + "/img_create_iot/img_boot2.bin")
                 d_addrs.append("00002000")
         elif chiptype == "bl702":
             bflb_utils.printf("========= copy bootinfo_boot2.bin =========")
-            bflb_utils.copyfile(chipname + "/img_create_iot/bootinfo.bin",
-                                chipname + "/img_create_iot/bootinfo_boot2.bin")
-            d_files.append(chipname + "/img_create_iot/bootinfo_boot2.bin")
+            bflb_utils.copyfile(chipnamedir + "/img_create_iot/bootinfo.bin",
+                                chipnamedir + "/img_create_iot/bootinfo_boot2.bin")
+            d_files.append("chips/" + chipname + "/img_create_iot/bootinfo_boot2.bin")
             d_addrs.append("00000000")
     
         if pt_parcel is not None and len(pt_parcel) > 0 and pt_parcel['pt_new'] is True:
-            d_files.append(chipname + "/partition/partition.bin")
+            d_files.append("chips/" + chipname + "/partition/partition.bin")
             d_addrs.append(hex(pt_parcel['pt_addr0'])[2:])
-            d_files.append(chipname + "/partition/partition.bin")
+            d_files.append("chips/" + chipname + "/partition/partition.bin")
             d_addrs.append(hex(pt_parcel['pt_addr1'])[2:])
     
         if bin_file is True and 'fw_cpu0_addr' in pt_parcel:
@@ -650,19 +654,19 @@ class BflbIotTool(object):
                 whole_img_len = 0x1000 + os.path.getsize(
                     chipnamedir + "/img_create_iot/img_cpu0.bin")
                 whole_img_data = bl_create_flash_default_data(whole_img_len)
-                filedata = bl_get_file_data([chipname + "/img_create_iot/bootinfo_cpu0.bin"])[0]
+                filedata = bl_get_file_data(["chips/" + chipname + "/img_create_iot/bootinfo_cpu0.bin"])[0]
                 whole_img_data[0:len(filedata)] = filedata
-                filedata = bl_get_file_data([chipname + "/img_create_iot/img_cpu0.bin"])[0]
+                filedata = bl_get_file_data(["chips/" + chipname + "/img_create_iot/img_cpu0.bin"])[0]
                 whole_img_data[0x1000:0x1000 + len(filedata)] = filedata
                 fp = open(whole_img, 'wb+')
                 fp.write(whole_img_data)
                 fp.close()
-                d_files.append(chipname + "/img_create_iot/whole_img_cpu0.bin")
+                d_files.append("chips/" + chipname + "/img_create_iot/whole_img_cpu0.bin")
                 d_addrs.append(hex(pt_parcel['fw_cpu0_addr'])[2:])
             else:
-                d_files.append(chipname + "/img_create_iot/bootinfo_cpu0.bin")
+                d_files.append("chips/" + chipname + "/img_create_iot/bootinfo_cpu0.bin")
                 d_addrs.append(hex(pt_parcel['fw_cpu0_addr'])[2:])
-                d_files.append(chipname + "/img_create_iot/img_cpu0.bin")
+                d_files.append("chips/" + chipname + "/img_create_iot/img_cpu0.bin")
                 d_addrs.append(hex(pt_parcel['fw_cpu0_addr'] + 0x1000)[2:])
     
         if bin_file is True and 'fw_addr' in pt_parcel:
@@ -671,29 +675,29 @@ class BflbIotTool(object):
                 whole_img_len = 0x1000 + os.path.getsize(
                     chipnamedir + "/img_create_iot/img.bin")
                 whole_img_data = bl_create_flash_default_data(whole_img_len)
-                filedata = bl_get_file_data([chipname + "/img_create_iot/bootinfo.bin"])[0]
+                filedata = bl_get_file_data(["chips/" + chipname + "/img_create_iot/bootinfo.bin"])[0]
                 whole_img_data[0:len(filedata)] = filedata
-                filedata = bl_get_file_data([chipname + "/img_create_iot/img.bin"])[0]
+                filedata = bl_get_file_data(["chips/" + chipname + "/img_create_iot/img.bin"])[0]
                 whole_img_data[0x1000:0x1000 + len(filedata)] = filedata
                 fp = open(whole_img, 'wb+')
                 fp.write(whole_img_data)
                 fp.close()
-                d_files.append(chipname + "/img_create_iot/whole_img.bin")
+                d_files.append("chips/" + chipname + "/img_create_iot/whole_img.bin")
                 d_addrs.append(hex(pt_parcel['fw_addr'])[2:])
             else:
-                d_files.append(chipname + "/img_create_iot/bootinfo.bin")
+                d_files.append("chips/" + chipname + "/img_create_iot/bootinfo.bin")
                 d_addrs.append(hex(pt_parcel['fw_addr'])[2:])
-                d_files.append(chipname + "/img_create_iot/img.bin")
+                d_files.append("chips/" + chipname + "/img_create_iot/img.bin")
                 d_addrs.append(hex(pt_parcel['fw_addr'] + 0x1000)[2:])
     
         if ro_params is not None and len(ro_params) > 0 and pt_parcel['conf_addr'] is not None:
             bl_ro_device_tree.bl_ro_params_device_tree(ro_params,
-                                                       chipname + "/device_tree/ro_params.dtb")
-            d_files.append(chipname + "/device_tree/ro_params.dtb")
+                                                       chipnamedir + "/device_tree/ro_params.dtb")
+            d_files.append("chips/" + chipname + "/device_tree/ro_params.dtb")
             d_addrs.append(hex(pt_parcel['conf_addr'])[2:])
     
         if media is True and pt_parcel['media_addr'] is not None:
-            d_files.append(chipname + "/img_create_iot/media.bin")
+            d_files.append("chips/" + chipname + "/img_create_iot/media.bin")
             d_addrs.append(hex(pt_parcel['media_addr'])[2:])
     
         if mfg is True:
@@ -702,19 +706,19 @@ class BflbIotTool(object):
                 whole_img_len = 0x1000 + os.path.getsize(
                     chipnamedir + "/img_create_iot/img_mfg.bin")
                 whole_img_data = bl_create_flash_default_data(whole_img_len)
-                filedata = bl_get_file_data([chipname + "/img_create_iot/bootinfo_mfg.bin"])[0]
+                filedata = bl_get_file_data(["chips/" + chipname + "/img_create_iot/bootinfo_mfg.bin"])[0]
                 whole_img_data[0:len(filedata)] = filedata
-                filedata = bl_get_file_data([chipname + "/img_create_iot/img_mfg.bin"])[0]
+                filedata = bl_get_file_data(["chips/" + chipname + "/img_create_iot/img_mfg.bin"])[0]
                 whole_img_data[0x1000:0x1000 + len(filedata)] = filedata
                 fp = open(whole_img, 'wb+')
                 fp.write(whole_img_data)
                 fp.close()
-                d_files.append(chipname + "/img_create_iot/whole_img_mfg.bin")
+                d_files.append("chips/" + chipname + "/img_create_iot/whole_img_mfg.bin")
                 d_addrs.append(hex(pt_parcel['mfg_addr'])[2:])
             else:
-                d_files.append(chipname + "/img_create_iot/bootinfo_mfg.bin")
+                d_files.append("chips/" + chipname + "/img_create_iot/bootinfo_mfg.bin")
                 d_addrs.append(hex(pt_parcel['mfg_addr'])[2:])
-                d_files.append(chipname + "/img_create_iot/img_mfg.bin")
+                d_files.append("chips/" + chipname + "/img_create_iot/img_mfg.bin")
                 d_addrs.append(hex(pt_parcel['mfg_addr'] + 0x1000)[2:])
     
         if len(d_files) > 0 and len(d_addrs) > 0:
@@ -739,7 +743,7 @@ class BflbIotTool(object):
     def bl60x_mfg_uart_flasher(self, uart, baudrate='57600', cfg_ini=None):
         self.bl60x_mfg_flasher_cfg(uart, baudrate, cfg_ini)
         exe_genitor([
-            'python', os.path.join(app_path, "libs/bflb_eflash_loader.py"), '--write', '--flash', '-c', self.eflash_loader_cfg
+            'python', os.path.join(chip_path, "libs/bflb_eflash_loader.py"), '--write', '--flash', '-c', self.eflash_loader_cfg
         ])
 
 
@@ -753,7 +757,7 @@ class BflbIotTool(object):
         boot2_en = False
         dts_bytearray = None
         
-        partition_path = os.path.join(app_path, chipname, "partition/partition.bin")
+        partition_path = os.path.join(chip_path, chipname, "partition/partition.bin")
         error = "Please check your partition table file"
         #gol.GlobalVar.values = config
         self.config = config
@@ -782,7 +786,27 @@ class BflbIotTool(object):
             bflb_utils.printf(error)
             bflb_utils.set_error_code("0070")
             return bflb_utils.errorcode_msg()
-    
+        
+        if config["check_box"]['ro_params_download'] is True:
+#             suffix = config['param'][chip_brd] + '_' + \
+#                 config['param'][chip_xtal] + '.dts'
+#             ro = os.path.join(chip_path, chipname, 'device_tree',
+#                               bl_factory_params_file_prefix + suffix)
+            ro = config['input_path']['dts_input']
+            if not os.path.isfile(ro):
+                bflb_utils.printf("Don't Find %s as bl_factory image" % ro)
+                error = "Don't Find %s as bl_factory image" % ro
+                bflb_utils.printf(error)
+                bflb_utils.set_error_code("0079")
+                return bflb_utils.errorcode_msg()
+            if ro is not None and len(ro) > 0:
+                ro_params_d = ro
+                try:
+                    dts_hex = bl_ro_device_tree.bl_dts2hex(ro_params_d)
+                    dts_bytearray = bflb_utils.hexstr_to_bytearray(dts_hex)
+                except Exception as e:
+                    dts_bytearray = None
+          
         pt = config['input_path']['pt_bin_input']
         if pt is not None and len(pt) > 0:
             pt_helper = partition.PtCreater(pt)
@@ -838,8 +862,8 @@ class BflbIotTool(object):
                 self.bl60x_fw_boot_head_gen(True, config['param'][chip_xtal], self.bh_cfg_file,
                                        config["check_box"]['encrypt'], config["check_box"]['sign'],
                                        chipname, chiptype, cpu_type, boot2_en)
-                f_org = os.path.join(app_path, chipname, "img_create_iot", "img_create_cfg_boot2.conf")
-                f = os.path.join(app_path, chipname, "img_create_iot", "img_create_cfg_boot2.ini")
+                f_org = os.path.join(chip_path, chipname, "img_create_iot", "img_create_cfg_boot2.conf")
+                f = os.path.join(chip_path, chipname, "img_create_iot", "img_create_cfg_boot2.ini")
                 if os.path.isfile(f) is False:
                     shutil.copy(f_org, f)
                 self.bl60x_image_gen(chipname, chiptype, cpu_type, "boot2", boot2,
@@ -851,26 +875,7 @@ class BflbIotTool(object):
             self.bl60x_fw_boot_head_gen(True, config['param'][chip_xtal], self.bh_cfg_file,
                                    config["check_box"]['encrypt'], config["check_box"]['sign'],
                                    chipname, chiptype, cpu_type, boot2_en)
-    
-        if config["check_box"]['ro_params_download'] is True:
-            suffix = config['param'][chip_brd] + '_' + \
-                config['param'][chip_xtal] + '.dts'
-            ro = os.path.join(app_path, chipname, 'device_tree',
-                              bl_factory_params_file_prefix + suffix)
-            if not os.path.isfile(ro):
-                bflb_utils.printf("Don't Find %s as bl_factory image" % ro)
-                error = "Don't Find %s as bl_factory image" % ro
-                bflb_utils.printf(error)
-                bflb_utils.set_error_code("0079")
-                return bflb_utils.errorcode_msg()
-            if ro is not None and len(ro) > 0:
-                ro_params_d = ro
-                try:
-                    dts_hex = bl_ro_device_tree.bl_dts2hex(ro_params_d)
-                    dts_bytearray = bflb_utils.hexstr_to_bytearray(dts_hex)
-                except Exception as e:
-                    dts_bytearray = None
-                
+                   
         if config["check_box"]['bin_download'] is True:
             bin = config['input_path']['cfg2_bin_input']
             if bin is not None and len(bin) > 0:
@@ -897,7 +902,7 @@ class BflbIotTool(object):
             media_bin = config['input_path']['meida_bin_input']
             if media_bin is not None and len(media_bin) > 0:
                 try:
-                    shutil.copy(media_bin, os.path.join(app_path, chipname, "img_create_iot", "media.bin"))
+                    shutil.copy(media_bin, os.path.join(chip_path, chipname, "img_create_iot", "media.bin"))
                 except Exception as e:
                     bflb_utils.printf(e)
             media_bin_d = True
@@ -906,7 +911,7 @@ class BflbIotTool(object):
             romfs_dir = config['input_path']['romfs_dir_input']
             if romfs_dir is not None and len(romfs_dir) > 0:
                 ret = generate_romfs_img(romfs_dir,
-                                         os.path.join(app_path, chipname, "img_create_iot", "media.bin"))
+                                         os.path.join(chip_path, chipname, "img_create_iot", "media.bin"))
                 if ret != 0:
                     bflb_utils.printf('ERROR, ret %s.' % ret)
                     error = 'ERROR, ret %s.' % ret
@@ -931,8 +936,8 @@ class BflbIotTool(object):
     
                 self.bl60x_mfg_boot_head_gen(hex(pt_parcel['mfg_addr']), config['param'][chip_xtal],
                                         self.bh_cfg_file, chipname, chiptype, cpu_type)
-                f_org = os.path.join(app_path, chipname, "img_create_iot", "img_create_cfg_mfg.conf")
-                f = os.path.join(app_path, chipname, "img_create_iot", "img_create_cfg_mfg.ini")
+                f_org = os.path.join(chip_path, chipname, "img_create_iot", "img_create_cfg_mfg.conf")
+                f = os.path.join(chip_path, chipname, "img_create_iot", "img_create_cfg_mfg.ini")
                 if os.path.isfile(f) is False:
                     shutil.copy(f_org, f)
                 self.bl60x_image_gen(chipname, chiptype, cpu_type, "mfg", mfg, 
@@ -949,8 +954,8 @@ class BflbIotTool(object):
         self.config = config
         error = None
         cpu_type = None   
-        ota_path = os.path.join(app_path, chipname, "ota")
-        imgcreate2_path = os.path.join(app_path, chipname, "img_create_mcu")
+        ota_path = os.path.join(chip_path, chipname, "ota")
+        imgcreate2_path = os.path.join(chip_path, chipname, "img_create_mcu")
         if not os.path.exists(ota_path):
             os.makedirs(ota_path)
         if not os.path.exists(imgcreate2_path):
@@ -988,7 +993,7 @@ class BflbIotTool(object):
     
             bl60x_xtal = config["param"][chip_xtal]
             bflb_utils.printf("eflash loader bin is " + get_eflash_loader(bl60x_xtal))
-            eflash_loader_bin = os.path.join(app_path, chipname,
+            eflash_loader_bin = os.path.join(chip_path, chipname,
                                              "eflash_loader/" + get_eflash_loader(bl60x_xtal))
     
             if config["check_box"]["download_single"] is True and act == "download":
@@ -999,7 +1004,7 @@ class BflbIotTool(object):
                 cfg.set('FLASH_CFG', 'file', files_str)
                 cfg.set('FLASH_CFG', 'address', addrs_str)
                 cfg.write(self.eflash_loader_cfg, 'w')
-                self.eflash_loader_t = eflash_loader.BflbEflashLoader(chiptype)
+                self.eflash_loader_t = eflash_loader.BflbEflashLoader(chipname, chiptype)
                 if config["check_box"]['ckb_erase_all'] == "True":
                     self.bl60x_mfg_flasher_erase_all(True)
                 else:
@@ -1018,7 +1023,7 @@ class BflbIotTool(object):
             elif self.flasher_download_cfg_ini_gen(chipname, chiptype, cpu_type, config) is True:
                 if act == "download":
                     # burn into flash
-                    self.eflash_loader_t = eflash_loader.BflbEflashLoader(chiptype)
+                    self.eflash_loader_t = eflash_loader.BflbEflashLoader(chipname, chiptype)
                     if config["check_box"]['ckb_erase_all'] == "True":
                         self.bl60x_mfg_flasher_erase_all(True)
                     else:
@@ -1030,7 +1035,7 @@ class BflbIotTool(object):
                         options.extend(["--efuse"])
                         if  config["check_box"]["encrypt"] is True or\
                             config["check_box"]["sign"] is True:
-                            cfg_file = os.path.join(app_path, chipname, "img_create_iot", "img_create_cfg.ini")
+                            cfg_file = os.path.join(chip_path, chipname, "img_create_iot", "img_create_cfg.ini")
                             options.extend(["--createcfg=" + cfg_file])
                     if config['param']['interface_type'] == 'Uart':
                         options.extend(["-p", uart])
@@ -1085,7 +1090,7 @@ def flasher_download_cmd(args):
 def iot_download_cmd(args):
     chipname = args.chipname
     chiptype = chip_dict.get(chipname, "unkown chip type") 
-    partition_cfg = os.path.join(app_path, chipname, "partition/partition_cfg_2M.toml") 
+    partition_cfg = os.path.join(chip_path, chipname, "partition/partition_cfg_2M.toml") 
     config = dict()
     config["param"] = dict()
     config["check_box"] = dict()
@@ -1094,7 +1099,6 @@ def iot_download_cmd(args):
     config["param"]["comport_uart"] =  args.port
     config["param"]["speed_uart"] = str(args.baudrate)
     config["param"]["speed_jlink"] = str(args.baudrate)
-    config["param"]["bl60x_brd"] = args.board
     config["param"]["bl60x_xtal"] = args.xtal
     config["param"]["aes_key"] = ""
     config["param"]["aes_iv"] = ""
@@ -1107,6 +1111,7 @@ def iot_download_cmd(args):
     config["check_box"]["ckb_erase_all"] = args.erase
     config["check_box"]["encrypt"] = False
     config["check_box"]["sign"] = False
+    config["input_path"]["dts_input"] = args.dts
     config["input_path"]["pt_bin_input"] = partition_cfg
     config["input_path"]["cfg2_bin_input"] = args.firmware
     config["input_path"]["meida_bin_input"] = ""
@@ -1125,32 +1130,32 @@ def iot_download_cmd(args):
             config["param"]["bl60x_xtal"] = "32M"
         else:   
             config["param"]["bl60x_xtal"] = args.xtal 
-        if not args.board: 
-            config["param"]["bl60x_brd"] = "IoTKitA"
+        if not args.dts: 
+            config["input_path"]["dts_input"] = os.path.join(chip_path, chipname, "device_tree/bl_factory_params_IoTKitA_32M.dts")
         else:   
-            config["param"]["bl60x_brd"] = args.board
+            config["input_path"]["dts_input"] = args.dts
     elif chiptype == "bl602":
         config["check_box"]["boot2_download"] = True
-        config["input_path"]["boot2_bin_input"] = os.path.join(app_path, chipname, "builtin_imgs", "blsp_boot2.bin")
+        config["input_path"]["boot2_bin_input"] = os.path.join(chip_path, chipname, "builtin_imgs", "blsp_boot2.bin")
         if not args.xtal: 
             config["param"]["bl60x_xtal"] = "40M"
         else:   
             config["param"]["bl60x_xtal"] = args.xtal 
-        if not args.board: 
-            config["param"]["bl60x_brd"] = "IoTKitA"
+        if not args.dts: 
+            config["input_path"]["dts_input"] = os.path.join(chip_path, chipname, "device_tree/bl_factory_params_IoTKitA_40M.dts")
         else:   
-            config["param"]["bl60x_brd"] = args.board
+            config["input_path"]["dts_input"] = args.dts
     elif chiptype == "bl60x":
         config["check_box"]["boot2_download"] = True
-        config["input_path"]["boot2_bin_input"] = os.path.join(app_path, chipname, "builtin_imgs", "blsp_boot2.bin")
+        config["input_path"]["boot2_bin_input"] = os.path.join(chip_path, chipname, "builtin_imgs", "blsp_boot2.bin")
         if not args.xtal: 
             config["param"]["bl60x_xtal"] = "38.4M"
         else:   
             config["param"]["bl60x_xtal"] = args.xtal 
-        if not args.board: 
-            config["param"]["bl60x_brd"] = "avb"
+        if not args.dts: 
+            config["input_path"]["dts_input"] = os.path.join(chip_path, chipname, "device_tree/bl_factory_params_avb_38.4M.dts")
         else:   
-            config["param"]["bl60x_brd"] = args.board
+            config["input_path"]["dts_input"] = args.dts
     else:
         bflb_utils.printf("Chip type is not in bl60x/bl602/bl702")
         return
@@ -1166,7 +1171,7 @@ def iot_download_cmd(args):
     obj_iot = BflbIotTool(chipname, chiptype)
     obj_iot.flasher_download_thread(chipname, chiptype, act, config)
     if act == "build":
-        f_org = os.path.join(app_path, args.chipname, "img_create_iot", "whole_flash_data.bin")
+        f_org = os.path.join(chip_path, args.chipname, "img_create_iot", "whole_flash_data.bin")
         f = "firmware.bin"
         shutil.copy(f_org, f)
     
@@ -1188,7 +1193,7 @@ def run():
     parser.add_argument("--port", dest="port", default=port, help="serial port to use")
     parser.add_argument("--baudrate", dest="baudrate", default=115200, type=int, help="the speed at which to communicate")
     parser.add_argument("--xtal", dest="xtal", help="xtal type")
-    parser.add_argument("--board", dest="board", help="board type")
+    parser.add_argument("--dts", dest="dts", help="device tree") 
     parser.add_argument("--firmware", dest="firmware", default=firmware_default, help="image to write")  
     parser.add_argument("--build", dest="build", action="store_true", help="build image") 
     parser.add_argument("--erase", dest="erase", action="store_true", help="chip erase")
